from math import sqrt


class Point:
    """n-dimensional point
    """

    # notice the function annotations below
    def __init__(self: "Point", coord: [float, ...]) -> None:
        """Initialize this point
        >>> p = Point([3, 4])
        """
        # list comprehensions --- [<expression> for x in iterable]
        # may be something new to you
        self._coord = [float(x) for x in coord]
    
    def distance(self: "Point") -> float:
        """distance from origin
        >>> p = Point([3, 4])
        >>> p.distance()
        5.0
        """
        return sqrt(sum([x**2 for x in self._coord]))

    def __eq__(self: "Point", other: "Point") -> bool:
        """
        self is equivalent to other.

        >>> p1 = Point([3, 4, 5])
        >>> p2 = Point([3.0, 4.0, 5.0])
        >>> p1 == p2
        True
        """
        return (isinstance(other, Point) and
                len(self.coord) == len(other.coord) and
                all([a == b for a, b in zip(self.coord, other.coord)]))

    def set_coord(self: "Points", coord: [float, ]) -> None:
        """Set coordinates for this point"""
        if '_coord' in dir(self):
            raise Exception('Cannot reset coords')
        else:
            self._coord = coord

    def get_coord(self: 'Point') -> [float, ...]:
        """Get coordinates for this Point"""
        return self._coord
    
    def permitted_coord_change(newcoord:[float,]) -> None:
        self.set_coord(newcoord)

    coord = property(get_coord, set_coord, None, None)

if __name__ == '__main__':
    import doctest
    doctest.testmod()
