from numbers import Number as Number

def sum_list_verbose(L:list) -> Number:
    """
    Return sum of the numbers in possibly-nested list L
    
    >>> sum_list_verbose([1, 2, 3])
    6
    >>> sum_list_verbose([1, [2, 3, [4]], 5])
    15
    """    
    total = 0
    for x in L:
        # If x is a number then it's clear what to do
        if isinstance(x,Number):        
            total += x
        else:
            # What do we do if x is not a number? 
            # Then x is a possibly-nested list of numbers, 
            # which is what sum_list_verbose works on!
            # And x is smaller than L!
            total += sum_list_verbose(x)
    return total    


# here's a more-concise version of the same function
def sum_list(L: list) -> Number:
    """
    Return sum of the numbers in possibly nested list L
    
    >>> sum_list([1, 2, 3])
    6
    >>> sum_list([1, [2, 3, [4]], 5])
    15
    """
    return sum([x if isinstance(x, Number) else sum_list(x) for x in L])


if __name__ == '__main__':
    import doctest
    doctest.testmod(verbose=True)
    
